==> webkit2gtk_2.30.3.orig.tar.xz: webkitgtk-2.30.3/Source/WebCore/platform/graphics/gpu/GPUErrorScopes.h <==
/*
 * Copyright (C) 2019 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(WEBGPU)

#include "GPUError.h"
#include "GPUErrorFilter.h"
#include <wtf/Function.h>
#include <wtf/Optional.h>
#include <wtf/Ref.h>
#include <wtf/RefCounted.h>
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>

namespace WebCore {

class GPUErrorScopes : public RefCounted<GPUErrorScopes> {
public:
    using UncapturedErrorCallback = Function<void(GPUError&&)>;
    static Ref<GPUErrorScopes> create(UncapturedErrorCallback&&);

    void pushErrorScope(GPUErrorFilter);
    Optional<GPUError> popErrorScope(String& failMessage);

    void generateError(const String&, GPUErrorFilter = GPUErrorFilter::Validation);
    void generatePrefixedError(const String&);
    void setErrorPrefix(const String& prefix) { m_prefix = prefix; }

private:
    struct ErrorScope {
        const GPUErrorFilter filter;
        Optional<GPUError> error;
    };

    GPUErrorScopes(UncapturedErrorCallback&&);

    UncapturedErrorCallback m_uncapturedErrorCallback;

    Vector<ErrorScope> m_errorScopes;
    String m_prefix;
    unsigned m_numUncapturedErrorEventsAllowed;
};

} // namespace WebCore

#endif // ENABLE(WEBGPU)

==> webkit2gtk_2.33.2.orig.tar.xz: webkitgtk-2.33.2/Source/WebCore/platform/graphics/gpu/GPUErrorScopes.h <==
/*
 * Copyright (C) 2019 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(WEBGPU)

#include "GPUError.h"
#include "GPUErrorFilter.h"
#include <wtf/Function.h>
#include <wtf/Ref.h>
#include <wtf/RefCounted.h>
#include <wtf/Vector.h>
#include <wtf/text/WTFString.h>

namespace WebCore {

class GPUErrorScopes : public RefCounted<GPUErrorScopes> {
public:
    using UncapturedErrorCallback = Function<void(GPUError&&)>;
    static Ref<GPUErrorScopes> create(UncapturedErrorCallback&&);

    void pushErrorScope(GPUErrorFilter);
    std::optional<GPUError> popErrorScope(String& failMessage);

    void generateError(const String&, GPUErrorFilter = GPUErrorFilter::Validation);
    void generatePrefixedError(const String&);
    void setErrorPrefix(const String& prefix) { m_prefix = prefix; }

private:
    struct ErrorScope {
        const GPUErrorFilter filter;
        std::optional<GPUError> error;
    };

    GPUErrorScopes(UncapturedErrorCallback&&);

    UncapturedErrorCallback m_uncapturedErrorCallback;

    Vector<ErrorScope> m_errorScopes;
    String m_prefix;
    unsigned m_numUncapturedErrorEventsAllowed;
};

} // namespace WebCore

#endif // ENABLE(WEBGPU)
